Sub Effic (d$,E,tAu,tD,tBe,tC,tDiam,tBN,tQ,tSiN,tM,tAl,tIce,t,Ef)

     'Subroutine:Si(Li) or Ge X-Ray Detector Efficiency,Zaluzec (1984)
     'Input parameters:      d$     :   detector type (Si or Ge)
     '                       E      :   energy in keV
     '                       tAu    :   Au layer thickness in microns
     '                       tD     :   Si dead layer thickness in microns
     '                       tBe    :   Be thickness in microns
     '                       tC     :   Carbon thickness in microns
     '                       tDiam  :   Diamond thickness in microns
     '                       tBN    :   BN thickness in microns
     '                       tQ     :   Kevex Quantum thickness in microns
     '                       tSiN   :   Si3N4 thickness in microns
     '                       tM     :   Maylar thickness in microns
     '                       tAl    :   Al thickness in microns
     '                       tIce   :   Ice (as Oxygen) thickness in microns
     '                       t      :   detector thickness in mm
     'Output parameters:     Ef     :   efficiency

     d$=ucase$(d$)
     L=12.3981/E
     'Calc mass absorption coefficients
     Z=1
      if E>0.679 and E<1.487 then
	    C=0.001472:n=3.359
	    M1=C*L^n
      elseif E>0.395 and E<0.679 then
	    C=0.001816:n=3.285
	    M1=C*L^n
      elseif E>0.185 and E<0.395 then
	    C=0.002138:n=3.231
	    M1=C*L^n
      else
	    call Mac4 (Z,E,M)
	    M1=M
      end if

     Z=4
     if E>0.679 and E<1.487 then
	    C=0.3102:n=3.001
	    M4=C*L^n
     elseif E>0.285 and E<0.679 then
	    C=0.5060:n=2.831
	    M4=C*L^n
     elseif E>0.185 and E<0.285 then
	    C=2.2480:n=2.419
	    M4=C*L^n
     else
	    call Mac4 (Z,E,M)
	    M4=M
     end if

     Z=5
     call Mac4 (Z,E,M)
     M5=M

     Z=6
     if E>0.705 and E<1.487 then
	    C=1.9660:n=2.788
	    M6=C*L^n
     elseif E>0.285 and E<0.705 then
	    C=4.1290:n=2.529
	    M6=C*L^n
     elseif E>0.185 and E<0.285 then
	    C=0.2572:n=2.404
	    M6=C*L^n
     else
	    call Mac4 (Z,E,M)
	    M6=M
     end if

     Z=7
     call Mac4 (Z,E,M)
     M7=M

     Z=8
     if E>0.532 and E<1.487 then
	    C=6.9980:N=2.573
	    M8=C*L^n
     elseif E>0.185 and E<0.532 then
	    C=0.4810:N=2.479
	    M8=C*L^n
     else
	    call Mac4 (Z,E,M)
	    M8=M
     end if

     Z=13
     if E>0.556 and E<1.487 then
	    C=1.2860:n=2.712
	    M13=C*L^n
     elseif E>0.185 and E<0.556 then
	    M13=-7.059e-4*L^4-4.815e-2*L^3+2.579e1*L^2-3.664e2*L+1801.0
     else
	    call Mac4 (Z,E,M)
	    M13=M
     end if

     Z=14
     if E>0.637 and E<1.485 then
	    C=1.759:n=2.706
	    M14=C*L^n
     elseif E>0.185 and E<0.637 then
	    M14=-2.407e-1*L^3+3.983e1*L^2-5.270e2*L+2278.0
     else
	    call Mac4 (Z,E,M)
	    M14=M
     end if

     Z=32
     call Mac4 (Z,E,M)
     M32=M

     Z=79
     if E>0.776 and E<1.487 then
	    C=41.17:n=1.906
	    M79=C*L^n
     elseif E>0.185 and E<0.776 then
	    M79=-4.411e-4*L^5+9.878e-2*L^4-8.218*L^3+3.020e2*L^2-4.466e3*L+29660.0
     else
	    call Mac4 (Z,E,M)
	    M79=M
     end if


     'Au layer
     SumAu=M79*19.3*tAu*1e-4
     'Si dead layer
     SumD=M14*2.33*tD*1e-4
     'Be window
     SumBe=M4*1.82*tBe*1e-4
     'Carbon layer
     SumC=M6*1.0*tC*1e-4
     'Diamond layer
     SumDiam=M6*3.515*tDiam*1e-4
     'BN layer
     MBN=0.43439*M5+0.56561*M7
     SumBN=MBN*2.25*tBN*1e-4
     'Kevex Quantum
     if E=0 then
	 MQ=0
     elseif E>0 and E<2.99 then
	 A1=46453
	 A2=19016
	 t1=0.1389
	 t2=0.8541
	 MQ=A1*exp(-E/t1)+A2*exp(-E/t2)
     else
	 MQ=0
     end if
     SumQ=MQ*1.40*tQ*1e-4
     'Si3N4
     MSiN=0.59942*M14+0.40058*M7
     SumSiN=MSiN*3.44*tSiN*1e-4
     'Maylar layer
     MM=0.92258*M6+0.07742*M1
     SumM=MM*1.37*tM*1e-4
     'Al layer
     SumAl=M13*2.69*tAl*1e-4
     'Ice layer
     SumIce=M8*0.69*tIce*1e-4
     if d$="SI" then
	'Si detector
	 Sum=M14*2.33*t*0.1
     elseif d$="GE" then
	 Sum=M32*5.307*t*0.1
     end if
     if Sum>=2000 then Sum=2000

     Sum1=SumAu+SumD+SumBe+SumDiam+SumBN+SumQ+SumSiN+SumM+SumAl+SumIce

     Ef=exp(-Sum1)*(1-exp(-Sum))

End Sub
