Sub PhiRhoZ2 (Z,A,E0,Ec,rhoz,PhiRhoZ)

     'Subroutine Phi-Rho-Z function, Packwood and Brown (1981)

     'Input parameters:   Z         :     Atomic number
     '                    A         :     Atomic weight
     '                    E0        :     Incident beam energy in keV
     '                    Ec        :     Critical excitation energy in keV
     '                    rhoz      :     Mass thickness in ug/cm^2
     'Output parameter:   PhiRhoZ   :     PhiRhoZ function

     U0=E0/Ec
     'Mean ionization potential, Berger and Selzer (1964)
     J=9.76*Z+58*Z^(-0.19)/1000     'in keV

     'Coefficient alpha, Packwood and Brown (1981)
     alpha=3.95e5*Z^0.95/(A*E0^1.25)
     alpa1=log(1.166*E0/J)
     alpha=alpha*(alpha1/(E0-Ec))^0.5

     'Coefficient beta, Packwood and Brown (1981)
     beta=0.4*alpha*Z^0.6

     'Coefficient gama, Packwood and Brown (1981)
     gama0=5*3.1415927/((U0-1)*log(U0))
     gama0=gama0*(log(U0)-5+5*U0^(-0.2))

     'Backscattering coefficient, Love and Scott (1978)
     eta20=(-52.3791+150.48371*Z-1.167373*Z^2+0.00716*Z^3)*1e-4
     eta1=(-1112.8+30.29*Z-0.15498*Z^2)*1e-4
     eta=eta20*(1+eta1*log(E0/20))

     'Phi(0) function, Love and Scott (1980)
     V=log(U0)
     IU0=0.33148*V+0.05596*V^2-0.06339*V^3+0.000947*V^4
     GU0=(1/U0)*(2.87898*V-1.51307*V^2+0.81312*V^3-0.08241*V^4)
     phi0=1+eta/(1+eta)*(IU0+GU0*log(1+eta))

     'Phi-Rho-Z function
     b1=(gama0-phi0)/gama0
     b2=exp(-beta*rhoz)
     b3=exp(-alpha^2*rhoz^2)
     PhiRhoZ=gama0*(1-b1*b2)*b3

End Sub
