Sub PhiRhoZ4 (Z,A,E0,Ec,rhoz,PhiRhoZ)

     'Subroutine Phi-Rho-Z function, Bastin et al (1986)

     'Input parameters:   Z         :     Atomic number
     '                    A         :     Atomic weight
     '                    E0        :     Incident beam energy in keV
     '                    Ec        :     Critical excitation energy in keV
     '                    rhoz      :     Mass thickness in ug/cm^2
     'Output parameter:   PhiRhoZ   :     PhiRhoZ function

     U0=E0/Ec
     'Mean ionization potential, Ruste (1979)
     J=9.29*Z*(1+1.287*Z^(-2/3))
     J=J/1000    'in keV

     'Coefficient alpha, Bastin (1986)
     alpha1=1.75e5/(E0^1.25*(U0-1)^0.55)
     alpha2=(log(1.166*E0/J)/Ec)^0.5
     alpha=alpha1*alpha2

     'Coefficient beta, Bastin (1986)
     n=Z/(0.4765+0.5473*Z)
     beta=0.4*alpha*(Z^n/A)

     'Coefficient gama, Bastin (1986)
     if U0>3 then
	  gama1=0.3384+0.4742*(U0-1)
	  gama=1+(U0-1)/gama1
     elseif U0<=1 and U0<=3 then
	  gama=(5*3.1459*U0)/((U0-1)*log(U0))
	  gama=gama0*(log(U0+1)-5+5*U0^(-0.2))
     end if

     'Backscattering coefficient, Love and Scott (1978)
     eta20=(-52.3791+150.48371*Z-1.167373*Z^2+0.00716*Z^3)*1e-4
     eta1=(-1112.8+30.29*Z-0.15498*Z^2)*1e-4
     eta=eta20*(1+eta1*log(E0/20))

     'Phi(0) function, Love and Scott (1980)
     V=log(U0)
     IU0=0.33148*V+0.05596*V^2-0.06339*V^3+0.000947*V^4
     GU0=(1/U0)*(2.87898*V-1.51307*V^2+0.81312*V^3-0.08241*V^4)
     phi0=1+eta/(1+eta)*(IU0+GU0*log(1+eta))

     'Phi-Rho-Z function, Packwood and Brown (1981)
     b1=(gama-phi0)/gama
     b2=exp(-beta*rhoz)
     b3=exp(-alpha^2*rhoz^2)
     PhiRhoZ=gama*(1-b1*b2)*b3

End Sub
