Sub PhiRhoZ5 (Z,A,E0,Ec,rhoz,PhiRhoZ)

     'Subroutine Phi-Rho-Z function, Bastin et al (1989)

     'Input parameters:   Z         :     Atomic number
     '                    A         :     Atomic weight
     '                    E0        :     Incident beam energy in keV
     '                    Ec        :     Critical excitation energy in keV
     '                    rhoz      :     Mass thickness in ug/cm^2
     'Output parameter:   PhiRhoZ   :     PhiRhoZ function

     U0=E0/Ec
     'Mean ionization potential, Zeller (1951,1953)
     J=Z*(10.04+8.25*exp(-Z/11.22))*1e-3   'in keV

     'Coefficient alpha, Bastin (1989)
     alpha1=2.1614e5*Z^1.163/((U0-1)^0.5*E0^1.25*A)
     alpha2=(log(1.166*E0/J)/Ec)^0.5
     alpha=alpha1*alpha2

     'Coefficient gama, Bastin (1989)
     if U0>6 then
	  gama=2.814333*U0^(0.262702*Z^(-0.1614454))
     elseif U0<=6 then
	  gama=3.98352*U0^(-0.0516861)*(1.276233-U0^(-1.25558*Z^(-0.1424549)))
     end if
     'Compensation for ultra-light element radiation
     if Ec<1.7 then
	  gama=gama*Ec/(-4.1878e-2+1.05975*Ec)
     end if

     'Phi(0) function, Pouchou and Pichoir (1986)
     eta1=1-exp(-0.015*Z^1.3)
     eta=1.75e-3*Z+0.37*eta1
     r=2-2.3*eta
     phi0=1+3.3*(1-1/(U0^r))*eta^1.2

     'Coefficient beta, Bastin (1989)
     F=((gama-(gama-phi0)*R)*sqr(3.1415927))/(2*alpha)

     if x>=0.9 and x<1 then beta1=0.9628832-0.9642440*x
     if x>0.8 and x<0.9 then beta1=1.122405-1.141942*x
     if x>0.7 and x<=0.8 then beta1=13.43810*exp(-5.180503*x)
     if x>0.57 and x<=0.7 then beta1=5.909606*exp(-4.015891*x)
     if x>0.306 and x<=0.57 then beta1=4.852357*exp(-3.680818*x)
     if x>0.102 and x<=0.306 then beta1=(1-0.5379956*x)/(1.685638*x)
     if x>0.03165 and x<=0.102 then beta1=(1-1.043744*x)/(1.604820*x)
     if x>0 and x<=0.03165 then beta1=(1-2.749786*x)/(1.447465*x)
     beta=beta1*(alpha*alpha)

     'Phi-Rho-Z function, Packwood and Brown (1981)
     b1=(gama-phi0)/gama
     b2=exp(-beta*rhoz)
     b3=exp(-alpha^2*rhoz^2)
     PhiRhoZ=gama*(1-b1*b2)*b3

End Sub
